================
HTTP File Server
================

A simple HTTP server command line tool implemented in Python 3 with `bottle.py <http://bottlepy.org>`_.

With file uploading feature.

With curl support.

With filter support:

* hidden
* shown
* file
* dir

Example ::

  $ curl http://localhost:8000?hidden?file
  $ curl --form "upload=@<filename>" http://localhost:8000
